
//this sketch was created by John Baichtal in 2017
//based on the Adafruit NeoPixel and RTC libraries


#include <Adafruit_NeoPixel.h>
#include <Wire.h>
#include "RTClib.h"

RTC_DS1307 RTC;


#define PIN 6

Adafruit_NeoPixel strip = Adafruit_NeoPixel(16, PIN, NEO_GRB + NEO_KHZ800);

/* TR Comment
   Looks like the comments for the time arrays have been corrected. Glad to see it.
*/

byte numberMatrix[60][8] = {  //array of numbers
  { //time 0
    2, 2, 2, 2, 2, 2, 2, 2  //all pixels red -- let's make Midnight be all red instead of all black
  },

  { //time 1
    1, 0, 0, 0, 0, 0, 0, 0 // pixel 1 is blue
  },

  { //time 2
    0, 1, 0, 0, 0, 0, 0, 0 // pixel 2 is blue
  },

  { //time 3
    0, 0, 1, 0, 0, 0, 0, 0 // pixel 3 is blue
  },

  { //time 4
    0, 0, 0, 1, 0, 0, 0, 0 // pixel 4 is blue
  },

  { //time 5
    0, 0, 0, 0, 1, 0, 0, 0 // pixel 5 is blue
  },

  { //time 6
    0, 0, 0, 0, 0, 1, 0, 0 // pixel 6 is blue
  },

  { //time 7
    0, 0, 0, 0, 0, 0, 1, 0 // pixel 7 is blue
  },

  { //time 8
    0, 0, 0, 2, 0, 0, 0, 0 // pixel 4 is red
  },

  { //time 9
    1, 0, 0, 2, 0, 0, 0, 0 // pixel 1 is blue and pixel 4 is red
  },

  { //time 10
    0, 0, 0, 0, 2, 0, 0, 0 // pixel 5 is red
  },

  { //time 11
    4, 0, 0, 0, 0, 0, 1, 0 // pixel 1 is yellow and pixel 7 is blue
  },

  { //time 12
    0, 0, 4, 0, 0, 0, 0, 0 // pixel 3 is yellow
  },

  { //time 13
    0, 0, 1, 0, 2, 0, 0, 0 // pixel 3 is blue and pixel 5 is red
  },

  { //time 14
    0, 0, 0, 0, 0, 0, 2, 0 // pixel 7 is red
  },

  { //time 15
    0, 0, 5, 0, 0, 0, 0, 0 // pixel 3 is green
  },

  { //time 16
    0, 0, 0, 4, 0, 0, 0, 0 // pixel 4 is yellow
  },

  { //time 17
    2, 0, 5, 0, 0, 0, 0, 0 // pixel 1 is red and pixel 3 is green
  },

  { //time 18
    0, 4, 0, 0, 2, 0, 0, 0 // pixel 2 is yellow and pixel 5 is red
  },

  { //time 19
    0, 0, 0, 0, 1, 0, 2, 0 // pixel 5 is blue and pixel 7 is red
  },

  { //time 20
    0, 0, 0, 0, 4, 0, 0, 0 // pixel 5 is yellow
  },

  { //time 21
    5, 0, 0, 0, 0, 0, 0, 2 // pixel 1 is green and pixel 8 is red
  },

  { //time 22
    0, 1, 0, 0, 4, 0, 0, 0 // pixel 2 is blue and pixel 5 is yellow
  },

  { //time 23
    0, 0, 5, 0, 0, 0, 0, 1 // pixel 3 is green and pixel 8 is blue
  },

  { //time 24
    0, 0, 0, 0, 0, 4, 0, 0 // pixel 6 is yellow
  },

  { //time 25
    0, 0, 0, 0, 5, 0, 0, 0 // pixel 5 is green
  },

  { //time 26
    0, 0, 0, 5, 0, 1, 0, 0 // pixel 4 is green and pixel 6 is blue
  },

  { //time 27
    0, 0, 0, 0, 5, 0, 1, 0 // pixel 5 is green and pixel 7 is blue
  },

  { //time 28
    0, 0, 0, 0, 0, 0, 4, 0 // pixel 7 is yellow
  },

  { //time 29
    5, 0, 0, 0, 0, 4, 0, 0 // pixel 1 is green and pixel 6 is yellow
  },

  { //time 30
    0, 0, 0, 0, 0, 5, 0, 0 // pixel 6 is green -- or maybe something fun to mark the half hour?
  },

  { //time 31
    0, 0, 1, 0, 0, 0, 4, 0 // pixel 3 is blue and pixel 7 is yellow
  },

  { //time 32
    0, 1, 0, 0, 0, 5, 0, 0 // pixel 2 is blue and pixel 6 is green
  },

  { //time 33
    5, 0, 0, 0, 0, 0, 4, 0 // pixel 2 is green and pixel 7 is yellow
  },

  { //time 34
    0, 0, 0, 1, 0, 5, 0, 0 // pixel 4 is blue and pixel 6 is green
  },

  { //time 35
    0, 0, 0, 0, 0, 0, 5, 0 // pixel 7 is green
  },

  { //time 36
    1, 0, 0, 0, 0, 0, 5, 0 // pixel 1 is blue and pixel 7 is green
  },

  { //time 37
    0, 0, 0, 0, 1, 0, 0, 4 // pixel 5 is blue and pixel 8 is yellow
  },

  { //time 38
    0, 0, 1, 0, 0, 0, 5, 0 // pixel 3 is blue and pixel 7 is green
  },

  { //time 39
    0, 0, 5, 0, 0, 4, 0, 0 // pixel 3 is green and pixel 6 is yellow
  },

  { //time 40
    0, 0, 0, 0, 0, 0, 0, 5 // pixel 8 is green
  },

  { //time 41
    1, 0, 0, 0, 0, 0, 0, 5 // pixel 1 is blue and pixel 8 is green
  },

  { //time 42
    0, 1, 0, 0, 0, 0, 0, 5 // pixel 2 is blue and pixel 8 is green
  },

  { //time 43
    0, 0, 1, 0, 0, 0, 0, 5 // pixel 3 is blue and pixel 8 is green
  },

  { //time 44
    0, 0, 0, 1, 0, 0, 0, 5 // pixel 4 is blue and pixel 8 is green
  },

  { //time 45
    0, 0, 0, 0, 1, 0, 0, 5 // pixel 5 is blue and pixel 8 is green
  },

  { //time 46
    0, 0, 2, 0, 0, 0, 0, 5 // pixel 3 is red and pixel 8 is green
  },

  { //time 47
    0, 0, 4, 0, 0, 0, 5, 0 // pixel 3 is yellow and pixel 7 is green
  },

  { //time 48
    0, 0, 0, 2, 0, 0, 0, 5 // pixel 4 is red and pixel 8 is green
  },

  { //time 49
    0, 0, 0, 0, 5, 4, 0, 0 // pixel 5 is green and pixel 6 is yellow
  },

  { //time 50
    0, 0, 0, 0, 2, 0, 0, 5 // pixel 5 is red and pixel 8 is green
  },

  { //time 51
    0, 0, 0, 4, 0, 0, 5, 0 // pixel 4 is yellow and pixel 7 is green
  },

  { //time 52
    0, 0, 0, 5, 0, 0, 0, 4 // pixel 4 is green and pixel 8 is yellow
  },

  { //time 53
    0, 0, 0, 0, 5, 0, 4, 0 // pixel 5 is green and pixel 7 is yellow
  },

  { //time 54
    0, 0, 0, 0, 0, 4, 0, 5 // pixel 6 is yellow and pixel 8 is green
  },

  { //time 55
    0, 0, 0, 0, 4, 0, 5, 0 // pixel 5 is yellow and pixel 7 is green
  },

  { //time 56
    0, 0, 0, 0, 0, 4, 0, 4 // pixel 6 is yellow and pixel 8 is yellow
  },

  { //time 57
    0, 0, 0, 0, 5, 0, 0, 4 // pixel 5 is green and pixel 8 is yellow
  },

  { //time 58
    0, 0, 0, 0, 0, 5, 4, 0 // pixel 6 is green and pixel 7 is yellow
  },

  { //time 59
    0, 0, 0, 0, 0, 4, 5, 0 // pixel 6 is yellow and pixel 7 is green
  },


};

void setup() {
  Serial.begin(57600);
  Wire.begin();
  RTC.begin();

  strip.begin();
  strip.show(); // Initialize all pixels to 'off'

  if (! RTC.isrunning()) {
    Serial.println("RTC is NOT running!");
    // following line sets the RTC to the date & time this sketch was compiled
    RTC.adjust(DateTime(__DATE__, __TIME__));
  }


}

void loop() {


  //determine time
  DateTime now = RTC.now();

  int hourDisplay = now.hour();
  int minuteDisplay = now.minute();

  Serial.println();
  Serial.print("time: ");
  Serial.print(hourDisplay);
  Serial.print(": ");
  Serial.print(minuteDisplay);

  Serial.println();
  Serial.print("hours: ");

  /* TR Comment
   I like the comment below and it's true for the way the code currently is.
   However, the design as shown in the chapter has the strips oriented
   as mirrors of each other. So if someone follows the chapter design
   their code won't work as intended.
   The two options are change the code to fit the chapters design, or change
   the chapter design so that the strips are in the same orientation.
  */
  
  //the time display assumes pixels 0-7 (strip one) display hours
  //and pixels 8-15 (strip two) display minutes.
  //this presents a problem when you reverse one of the strips.
  //Make sure to have the strips oriented the same way.


  //hour display
  for (int thisPin = 0; thisPin < 8; thisPin++) {

    int LEDcolor = numberMatrix[hourDisplay][thisPin];

   /* TR Comment
      I like this new serial output
   */
    Serial.print(LEDcolor);

    switch (LEDcolor) {

      case 0:
        strip.setPixelColor (thisPin, 0, 0, 0);
        break;

      case 1: //make that pixel blue
        strip.setPixelColor (thisPin, 0, 0, 100);
        break;

      case 2: //make that pixel red
        strip.setPixelColor (thisPin, 100, 0, 0);
        break;
      
      /* TR Comment
         This feels like it may be more a question for the editor but
         is there any intention of adding a third case? Feels odd to just leave
         it like it is right now.
      */
      //nixed orange (3) because it was hard to tell from yellow
      //if you decide you want a 3, you can add it here. Maybe purple?

      case 4: //make that pixel yellow
        strip.setPixelColor (thisPin, 100, 50, 0);
        break;

      case 5: //make that pixel green
        strip.setPixelColor (thisPin, 0, 100, 00);
        break;

    }

  }

  //minute display
  Serial.println();
  Serial.print("minutes: ");

  for (int thisPin = 0; thisPin < 8; thisPin++) {
    int LEDcolor = numberMatrix[minuteDisplay][thisPin];

    Serial.print(LEDcolor);

    switch (LEDcolor) {

      case 0:
        strip.setPixelColor ((thisPin + 8), 0, 0, 0);
        break;

      case 1:
        strip.setPixelColor ((thisPin + 8), 0, 0, 100);
        break;

      case 2:
        strip.setPixelColor ((thisPin + 8), 100, 0, 0);
        break;

      case 4:
        strip.setPixelColor ((thisPin + 8), 100, 50, 0);
        break;

      case 5:
        strip.setPixelColor ((thisPin + 8), 0, 100, 0);
        break;

    }
    strip.show();

  }
  Serial.println();
  delay(1000);

  
  /* TR Comment
   Looks like the if statement for the button was removed.
   I'm guessing this is just to make writing the core logic easier
   but I just want to make sure that being able to switch the LEDs
   on/off if the button is coming back.
  */
}


